satsim.tfa.utils package — SatSim 0.20.1 documentation

# satsim.tfa.utils package

## Submodules

## satsim.tfa.utils.test_utils module

Utilities for testing Addons.

satsim.tfa.utils.test_utils.assert_allclose_according_to_type(a, b, rtol=1e-06, atol=1e-06, float_rtol=1e-06, float_atol=1e-06, half_rtol=0.001, half_atol=0.001, bfloat16_rtol=0.01, bfloat16_atol=0.01)

  Similar to tf.test.TestCase.assertAllCloseAccordingToType() but this doesn’t need a subclassing to run.

satsim.tfa.utils.test_utils.assert_not_allclose(a, b, **kwargs)

  Assert that two numpy arrays, do not have near values.

  Parameters:

    - a – the first value to compare.

    - b – the second value to compare.

    - **kwargs – additional keyword arguments to be passed to the underlying np.testing.assert_allclose call.

  Raises:

    AssertionError – If a and b are unexpectedly close at all elements.

## satsim.tfa.utils.types module

Types for typing functions signatures.